# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UrlSsrfThreatDetectionResponseFull(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'clean_url': 'bool',
        'threat_level': 'str'
    }

    attribute_map = {
        'clean_url': 'CleanURL',
        'threat_level': 'ThreatLevel'
    }

    def __init__(self, clean_url=None, threat_level=None):  # noqa: E501
        """UrlSsrfThreatDetectionResponseFull - a model defined in Swagger"""  # noqa: E501

        self._clean_url = None
        self._threat_level = None
        self.discriminator = None

        if clean_url is not None:
            self.clean_url = clean_url
        if threat_level is not None:
            self.threat_level = threat_level

    @property
    def clean_url(self):
        """Gets the clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501

        True if the URL is clean, false if it is at risk of containing an SSRF threat or attack  # noqa: E501

        :return: The clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._clean_url

    @clean_url.setter
    def clean_url(self, clean_url):
        """Sets the clean_url of this UrlSsrfThreatDetectionResponseFull.

        True if the URL is clean, false if it is at risk of containing an SSRF threat or attack  # noqa: E501

        :param clean_url: The clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :type: bool
        """

        self._clean_url = clean_url

    @property
    def threat_level(self):
        """Gets the threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501

        Threat level of the URL; possible values are High, Medium, Low and None  # noqa: E501

        :return: The threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :rtype: str
        """
        return self._threat_level

    @threat_level.setter
    def threat_level(self, threat_level):
        """Sets the threat_level of this UrlSsrfThreatDetectionResponseFull.

        Threat level of the URL; possible values are High, Medium, Low and None  # noqa: E501

        :param threat_level: The threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :type: str
        """

        self._threat_level = threat_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UrlSsrfThreatDetectionResponseFull, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlSsrfThreatDetectionResponseFull):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
