# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_security_api_client
from cloudmersive_security_api_client.models.string_automatic_threat_detection import StringAutomaticThreatDetection  # noqa: E501
from cloudmersive_security_api_client.rest import ApiException


class TestStringAutomaticThreatDetection(unittest.TestCase):
    """StringAutomaticThreatDetection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStringAutomaticThreatDetection(self):
        """Test StringAutomaticThreatDetection"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_security_api_client.models.string_automatic_threat_detection.StringAutomaticThreatDetection()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
