# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_security_api_client
from cloudmersive_security_api_client.api.content_threat_detection_api import ContentThreatDetectionApi  # noqa: E501
from cloudmersive_security_api_client.rest import ApiException


class TestContentThreatDetectionApi(unittest.TestCase):
    """ContentThreatDetectionApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_security_api_client.api.content_threat_detection_api.ContentThreatDetectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_content_threat_detection_automatic_threat_detection_string(self):
        """Test case for content_threat_detection_automatic_threat_detection_string

        Automatically detect threats in an input string  # noqa: E501
        """
        pass

    def test_content_threat_detection_check_sql_injection_string(self):
        """Test case for content_threat_detection_check_sql_injection_string

        Check text input for SQL Injection (SQLI) attacks  # noqa: E501
        """
        pass

    def test_content_threat_detection_check_xxe(self):
        """Test case for content_threat_detection_check_xxe

        Protect text input from XML External Entity (XXE) attacks  # noqa: E501
        """
        pass

    def test_content_threat_detection_detect_insecure_deserialization_json_string(self):
        """Test case for content_threat_detection_detect_insecure_deserialization_json_string

        Detect Insecure Deserialization JSON (JID) attacks in a string  # noqa: E501
        """
        pass

    def test_content_threat_detection_protect_xss(self):
        """Test case for content_threat_detection_protect_xss

        Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
